==> webgen-0.1.tgz: webgen-0.1/gen.php <==
<? 
 /***********************************************************
  ݭn[WܴC
 *************************************************************/
 require("config.php");
 require("dbconfig.php");
 require("auth.php");
/****** O޲z̪ܴNಣ *******/
 if (!in_array($PHP_AUTH_USER,$MANAGER))
 {
	echo "KKI$PHP_AUTH_USER AO޲z̡AMಣͭI<br>";
	exit;
 }
 /*****	XnͪM *******/
   $QUERY="select ptab,pname,ctlfile,target from main where ptab like '$key%'";
   $result=db_exec($db_conn,$QUERY);
   if (!$result){
        echo "MƬd߿~AO $QUERY !";
        exit;
   }
   $numrow=db_NumRows($result);
   if ($numrow==0){
        echo "MƬdߧ䤣ơAO $QUERY !";
        exit;
   }
   if ($day1>$day2) //SWAP
   {
	$tmp=$day1;
	$day1=$day2;
	$day2=$tmp;
   }
   /*****  ******/
   if ($ALLYN)
   {
	$MAINCONF=$CDIR."main.cfg";
	if (file_exists($MAINCONF))
 		$OUTMAIN=join( "", file( $MAINCONF ) );
	else
	{
		echo "ɮ $MAINCONF sbI<br>\n";
	}
   }
   /***** ql ******/
   if ($MAILYN)
   {
	$MAILCONF=$CDIR."mail.cfg";
	if (file_exists($MAILCONF))
 		$OUTMAIL=join( "", file( $MAILCONF ) );
	else
	{
		echo "ɮ $MAILCONF sbI<br>\n";
	}
   }
   /****BzC@ӱM****/
   for ($i=0;$i<$numrow;$i++)
   {
   	$ARAW=db_fetch_row($result,$i); //Ū@MyzɰO
	$prjq="select * from $ARAW[0] where pubtime>='$day1' and pubtime<='$day2' order by pubtime DESC";
   	$res=db_exec($db_conn,$prjq);
   	if (!$res){
        	echo "MƬd߿~AO $prjq !";
        	exit;
   	}
   	$numr=db_NumRows($res); //onBz峹
   	if ($numr==0){
        	echo "MƬdߧ䤣ơAO $prjq !";
		db_freeresult($res);
		continue;
   	}
	echo "=========}lBz$ARAW[3]M=========<br>\n";
	/******ˬdPإߥؿ*********/
	$DESTDIR=$BASEDIR.trim($ARAW[3]);
	$GBDESTDIR=$GBBASEDIR.trim($ARAW[3]);
	if (!is_dir($DESTDIR))
 	{
		echo "$DESTDIR sbI<br>\n";
	 	if (!mkdir($DESTDIR,0755)) echo "إ$DESTDIR ؿ!<br>\n";
		else echo "إ$DESTDIR ؿ\!<br>\n";
	}
	if (!is_dir($GBDESTDIR))
 	{
		echo "$GBDESTDIR sbI<br>\n";
	 	if (!mkdir($GBDESTDIR,0755)) echo "إ$GBDESTDIR ²ؿ!<br>\n";
		else echo "إ$GBDESTDIR ²ؿ\!<br>\n";
	}
	$DESTDIR=$BASEDIR.trim($ARAW[3])."/";
	$GBDESTDIR=$GBBASEDIR.trim($ARAW[3])."/";
	/********************* קKɮ
	exec("/bin/rm -f ".$DESTDIR."*"); //eͪɮ
	echo "/bin/rm -f ".$DESTDIR."*<br>";
	*********************/
        $CONF=$CDIR.trim($ARAW[2]).".cfg";  //峹榡
        $ICONF=$CDIR.trim($ARAW[2]).".cfi";  //ޮ榡
	//echo "conf=$CONF<br>";
   	$PARAW=db_fetch_row($res,0); //Ū@M峹O
	$fn1=$DESTDIR.trim($ARAW[0]).$PARAW[0].".html";
	$gbfn1=$AUTOCONV." > ".$GBDESTDIR.trim($ARAW[0]).$PARAW[0].".html";
	if (file_exists($ICONF))
 		$OUTIND=join( "", file( $ICONF ) );
	else
	{
		echo "ɮ $ICONF sbI<br>\n";
	}
	if (strstr($OUTIND,"<!--TABLE-->"))
        {
		$pt=strpos($OUTIND,"%bd%=");
 		$pt1=strpos($OUTIND,"%end%");
		$BDPAT=substr($OUTIND,$pt+5,$pt1-$pt-5);
		$OUTIND=substr($OUTIND,0,$pt-1).substr($OUTIND,$pt1+5);
		$PARAW1=$PARAW;
		$tabmode=1;
		$BDTXT="";
	}
	else $tabmode=0;
	/****ഫ` ****/
	if ($ALLYN)
	{
		$k="{".trim($ARAW[0])."}";
		$OUTMAIN=str_replace("%${k}ptab%",trim($ARAW[0]),$OUTMAIN);
		$OUTMAIN=str_replace("%${k}pname%",trim($ARAW[1]),$OUTMAIN);
	}
	/****ഫql ****/
	if ($MAILYN)
	{
		$k="{".trim($ARAW[0])."}";
		$OUTMAIL=str_replace("%${k}ptab%",trim($ARAW[0]),$OUTMAIL);
		$OUTMAIL=str_replace("%${k}pname%",trim($ARAW[1]),$OUTMAIL);
	}
   	for ($j=1;$j<=$numr;$j++)
   	{
	  if ($tabmode)
	  	$BDMSG="<tr>$BDPAT</tr>\n";
	  if (file_exists($CONF))
 	  	$OUT1=join( "", file( $CONF ) );
	  else
	  {
		echo "ɮ $CONF sbI<br>\n";
	  }
	  $fp1=fopen($fn1,"w");
	  $gbfp1=popen($gbfn1,"w");
	  echo "͡G$fn1P$gbfn1<br>\n";
	  /****** ഫ *****/
	  $OUT1=str_replace("%oid%",$PARAW[0],$OUT1); //aid
	  $OUT1=str_replace("%title%",trim($PARAW[1]),$OUT1); //title
	  $OUT1=str_replace("%author%",trim($PARAW[2]),$OUT1); //author
	  $OUT1=str_replace("%pubtime%",$PARAW[3],$OUT1); //ptime
	  $OUT1=str_replace("%abst%",$PARAW[4],$OUT1); //abst
	  $OUT1=str_replace("%txt%",$PARAW[5],$OUT1); //txt
	  $OUT1=str_replace("%email%",trim($PARAW[6]),$OUT1); //email
	  $OUT1=str_replace("%username%",trim($PARAW[7]),$OUT1); //username
	  if ($tabmode)
	  {
		$BDMSG=str_replace("%title%",trim($PARAW[1]),$BDMSG);
		$BDMSG=str_replace("%author%",trim($PARAW[2]),$BDMSG);
		$BDMSG=str_replace("%pubtime%",trim($PARAW[3]),$BDMSG);
		$BDMSG=str_replace("%abst%",trim($PARAW[4]),$BDMSG);
		$BDMSG=str_replace("%txt%",trim($PARAW[5]),$BDMSG);
		$BDMSG=str_replace("%email%",trim($PARAW[6]),$BDMSG);
		$BDMSG=str_replace("%username%",trim($PARAW[7]),$BDMSG);
 	  }
	  if ($ALLYN)
	  {
		$k="{".trim($ARAW[0])."}T$j";
		$OUTMAIN=str_replace("%${k}title%",trim($PARAW[1]),$OUTMAIN);
	  	$OUTMAIN=str_replace("%${k}author%",trim($PARAW[2]),$OUTMAIN); 
	  	$OUTMAIN=str_replace("%${k}pubtime%",trim($PARAW[3]),$OUTMAIN);
	  	$OUTMAIN=str_replace("%${k}abst%",trim($PARAW[4]),$OUTMAIN);
	  	$OUTMAIN=str_replace("%${k}txt%",trim($PARAW[5]),$OUTMAIN);
	  	$OUTMAIN=str_replace("%${k}email%",trim($PARAW[6]),$OUTMAIN);
	  	$OUTMAIN=str_replace("%${k}username%",trim($PARAW[7]),$OUTMAIN);
	  }
	  if ($MAILYN)
	  {
		$k="{".trim($ARAW[0])."}T$j";
		$OUTMAIL=str_replace("%${k}title%",trim($PARAW[1]),$OUTMAIL);
	  	$OUTMAIL=str_replace("%${k}author%",trim($PARAW[2]),$OUTMAIL); 
	  	$OUTMAIL=str_replace("%${k}pubtime%",trim($PARAW[3]),$OUTMAIL);
	  	$OUTMAIL=str_replace("%${k}abst%",trim($PARAW[4]),$OUTMAIL);
	  	$OUTMAIL=str_replace("%${k}txt%",trim($PARAW[5]),$OUTMAIL);
	  	$OUTMAIL=str_replace("%${k}email%",trim($PARAW[6]),$OUTMAIL);
	  	$OUTMAIL=str_replace("%${k}username%",trim($PARAW[7]),$OUTMAIL);
	  }
	  $OUTIND=str_replace("%T${j}title%",trim($PARAW[1]),$OUTIND); 
	  $OUTIND=str_replace("%T${j}author%",trim($PARAW[2]),$OUTIND); 
	  $OUTIND=str_replace("%T${j}pubtime%",trim($PARAW[3]),$OUTIND);
	  $OUTIND=str_replace("%T${j}abst%",trim($PARAW[4]),$OUTIND);
	  $OUTIND=str_replace("%T${j}email%",trim($PARAW[6]),$OUTIND);
	  $OUTIND=str_replace("%T${j}username%",trim($PARAW[7]),$OUTIND);
	  $ofn1=trim($ARAW[0]).$PARAW[0].".html";
	  $OUTIND=str_replace("%T${j}url%",$ofn1,$OUTIND);
	  $OUT1=str_replace("%T${j}oid%",$PARAW[0],$OUT1); //aid
	  $OUT1=str_replace("%T${j}title%",trim($PARAW[1]),$OUT1); //title
	  $OUT1=str_replace("%T${j}author%",trim($PARAW[2]),$OUT1); //author
	  $OUT1=str_replace("%T${j}pubtime%",$PARAW[3],$OUT1); //ptime
	  $OUT1=str_replace("%T${j}abst%",$PARAW[4],$OUT1); //abst
	  $OUT1=str_replace("%T${j}txt%",$PARAW[5],$OUT1); //txt
	  $OUT1=str_replace("%T${j}email%",trim($PARAW[6]),$OUT1); //email
	  $OUT1=str_replace("%T${j}username%",trim($PARAW[7]),$OUT1); //username
	  if ($tabmode)
		$BDMSG=str_replace("%url%",$ofn1,$BDMSG);
	  if ($ALLYN)
	  {
	 	$mainofn1=trim($ARAW[0])."/".$ofn1;
	  	$OUTMAIN=str_replace("%${k}url%",$mainofn1,$OUTMAIN);
	  }
	  if ($MAILYN)
	  {
	 	$mailofn1=trim($ARAW[0])."/".$ofn1;
	  	$OUTMAIL=str_replace("%${k}url%",$mailofn1,$OUTMAIL);
	  }
	  $ofn1=trim($ARAW[0]).$PARAW1[0].".html";
	  $OUT1=str_replace("%next%",$ofn1,$OUT1); //next file
	  
	  $PARAW1=$PARAW;
	  if ($j<$numr)
   	  	$PARAW=db_fetch_row($res,$j); //Ū@M峹O
	  $fn1=$DESTDIR.trim($ARAW[0]).$PARAW[0].".html";
	  $gbfn1=$AUTOCONV." > ".$GBDESTDIR.trim($ARAW[0]).$PARAW[0].".html";
	  $ofn1=trim($ARAW[0]).$PARAW[0].".html";
	  $OUT1=str_replace("%prev%",$ofn1,$OUT1); //previous file
	  fputs($fp1,$OUT1);
	  $GBOUT1=str_replace("charset=big5","charset=gb2312",$OUT1);
	  fputs($gbfp1,$GBOUT1);
	  fclose($fp1);
	  pclose($gbfp1);
	  if ($j==1) //峹
	  {
	    $indfn=$DESTDIR.$NEWFILE;
	    $gbindfn=$AUTOCONV." > ".$GBDESTDIR.$NEWFILE;
	    echo "big5=$indfn, $gbindfn<br>";
	    $fp1=fopen($indfn,"w");
	    $gbfp1=popen($gbindfn,"w");
	    fputs($fp1,$OUT1);
	    $GBOUT1=str_replace("charset=big5","charset=gb2312",$OUT1);
	    fputs($gbfp1,$GBOUT1);
	    fclose($fp1);
	    pclose($gbfp1);
	  }
	  if ($tabmode) $BDTXT=$BDTXT.$BDMSG;
	}
	db_freeresult($res);
	if ($tabmode)
		$OUTIND=str_replace("%body%",$BDTXT,$OUTIND);
        /**** 	X ******/
	$fnind=$DESTDIR.$INDFILE;
	$gbfnind=$AUTOCONV." > ".$GBDESTDIR.$INDFILE;
	$fpind=fopen($fnind,"w");
	$gbfpind=popen($gbfnind,"w");
	fputs($fpind,$OUTIND);
	$OUTIND=str_replace("charset=big5","charset=gb2312",$OUTIND);
	fputs($gbfpind,$OUTIND);
	fclose($fpind);
	pclose($gbfpind);
   }
 	db_freeresult($result);
	/***** X` ****/
	if ($ALLYN)
	{
		$fnind=$BASEDIR.$ALLIND;
		$gbfnind=$AUTOCONV." > ".$GBBASEDIR.$ALLIND;
		$fpind=fopen($fnind,"w");
		$gbfpind=popen($gbfnind,"w");
		fputs($fpind,$OUTMAIN);
		$OUTMAIN=str_replace("charset=big5","charset=gb2312",$OUTMAIN);
		fputs($gbfpind,$OUTMAIN);
		echo "Bz $fnind, $gbfnind<br>\n";
		fclose($fpind);
		pclose($gbfpind);
	}
	/***** XqlAqlNBig5XYi ****/
	if ($MAILYN)
	{
		$fnind=$BASEDIR.$MAILIND;
		$fpind=fopen($fnind,"w");
		fputs($fpind,$OUTMAIL);
		fclose($fpind);
	}
?>

==> webgen-0.2.tgz: webgen-0.2/gen.php <==
<? 
 /***********************************************************
  ݭn[WܴC
 *************************************************************/
 require("config.php");
 require("dbconfig.php");
 require("auth.php");
/****** O޲z̪ܴNಣ *******/
 if (!in_array($PHP_AUTH_USER,$MANAGER))
 {
	echo "KKI$PHP_AUTH_USER AO޲z̡AMಣͭI<br>";
	exit;
 }
 /*****	XnͪM *******/
   $QUERY="select ptab,pname,ctlfile,target from main where ptab like '$key%'";
   $result=db_exec($db_conn,$QUERY);
   if (!$result){
        echo "MƬd߿~AO $QUERY !";
        exit;
   }
   $numrow=db_NumRows($result);
   if ($numrow==0){
        //echo "MƬdߧ䤣ơAO $QUERY !";
	echo "$key MƬdߨS!<br>\n";
        exit;
   }
   if ($day1>$day2) //SWAP
   {
	$tmp=$day1;
	$day1=$day2;
	$day2=$tmp;
   }
   /*****  ******/
   if ($ALLYN)
   {
	$MAINCONF=$CDIR."main.cfg";
	if (file_exists($MAINCONF))
 		$OUTMAIN=join( "", file( $MAINCONF ) );
	else
	{
		echo "`ޮ榡ɮ $MAINCONF sbI<br>\n";
	}
   }
   /***** ql ******/
   if ($MAILYN)
   {
	$MAILCONF=$CDIR."mail.cfg";
	if (file_exists($MAILCONF))
 		$OUTMAIL=join( "", file( $MAILCONF ) );
	else
	{
		echo "ql榡ɮ $MAILCONF sbI<br>\n";
	}
   }
   /****BzC@ӱM****/
   for ($i=0;$i<$numrow;$i++) //]LC@ӱM
   {
   	$ARAW=db_fetch_row($result,$i); //Ū@MyzɰO
	$prjq="select * from $ARAW[0] where pubtime>='$day1' and pubtime<='$day2' order by pubtime DESC";
   	$res=db_exec($db_conn,$prjq);
   	if (!$res){
        	echo "MƬd߿~AO $prjq !<br>\n";
        	exit;
   	}
   	$numr=db_NumRows($res); //onBz峹
   	if ($numr==0){
			echo "$ARAW[0] MS峹I<br>\n";
        		//echo "MƬdߧ䤣ơAO $prjq !";
		db_freeresult($res);
		continue;
   	}
	echo "=========}lBz$ARAW[3]M=========<br>\n";
	/******ˬdPإߥؿ*********/
	$DESTDIR=$BASEDIR.trim($ARAW[3]);
	$GBDESTDIR=$GBBASEDIR.trim($ARAW[3]);
	if (!is_dir($DESTDIR))
 	{
		echo "$DESTDIR sbI<br>\n";
	 	if (!mkdir($DESTDIR,0755)) echo "إ$DESTDIR ؿ!<br>\n";
		else echo "إ$DESTDIR ؿ\!<br>\n";
	}
	if (!is_dir($GBDESTDIR))
 	{
		echo "$GBDESTDIR sbI<br>\n";
	 	if (!mkdir($GBDESTDIR,0755)) echo "إ$GBDESTDIR ²ؿ!<br>\n";
		else echo "إ$GBDESTDIR ²ؿ\!<br>\n";
	}
	$DESTDIR=$BASEDIR.trim($ARAW[3])."/";
	$GBDESTDIR=$GBBASEDIR.trim($ARAW[3])."/";
	/********************* קKɮ
	exec("/bin/rm -f ".$DESTDIR."*"); //eͪɮ
	echo "/bin/rm -f ".$DESTDIR."*<br>";
	*********************/
        $CONF=$CDIR.trim($ARAW[2]).".cfg";  //峹榡
        $ICONF=$CDIR.trim($ARAW[2]).".cfi";  //ޮ榡
	//echo "conf=$CONF<br>";
   	$PARAW=db_fetch_row($res,0); //Ū@M峹O
	$fn1=$DESTDIR.trim($ARAW[0]).$PARAW[0].".html";
	$gbfn1=$AUTOCONV." > ".$GBDESTDIR.trim($ARAW[0]).$PARAW[0].".html";
        /***** OUTIND  ̭sM
                OUT1   ̭sC@g峹
               OUTMAIN ̭`
               OUTMAIL ̭ql
                ARAW }CMyz
                PARAW}CM椤C@g*****/
	if (file_exists($ICONF))
 		$OUTIND=join( "", file( $ICONF ) );
	else
	{
		echo "Mޮ榡ɮ $ICONF sbI<br>\n";
	}
	if (strstr($OUTIND,"<!--TABLE-->"))
        {
		$pt=strpos($OUTIND,"%bd%=");
 		$pt1=strpos($OUTIND,"%end%");
		$BDPAT=substr($OUTIND,$pt+5,$pt1-$pt-5);
		$OUTIND=substr($OUTIND,0,$pt-1).substr($OUTIND,$pt1+5);
		$PARAW1=$PARAW;
		$tabmode=1;
		$BDTXT="";
	}
	else $tabmode=0;
	 /******ഫM*******/
          $OUTIND=str_replace("%ptab%",trim($ARAW[0]),$OUTIND);
          $OUTIND=str_replace("%pname%",trim($ARAW[1]),$OUTIND);
	/****ഫ` ****/
	if ($ALLYN)
	{
		$k="{".trim($ARAW[0])."}";
		$OUTMAIN=str_replace("%${k}ptab%",trim($ARAW[0]),$OUTMAIN);
		$OUTMAIN=str_replace("%${k}pname%",trim($ARAW[1]),$OUTMAIN);
	}
	/****ഫql ****/
	if ($MAILYN)
	{
		$k="{".trim($ARAW[0])."}";
		$OUTMAIL=str_replace("%${k}ptab%",trim($ARAW[0]),$OUTMAIL);
		$OUTMAIL=str_replace("%${k}pname%",trim($ARAW[1]),$OUTMAIL);
	}
   	for ($j=1;$j<=$numr;$j++) //]M椺C@g峹
   	{
	  if ($tabmode)
	  	$BDMSG="<tr>$BDPAT</tr>\n";
	  if (file_exists($CONF))
 	  	$OUT1=join( "", file( $CONF ) );
	  else
	  {
		echo "峹榡ɮ $CONF sbI<br>\n";
	  }
	  $fp1=fopen($fn1,"w");
	  $gbfp1=popen($gbfn1,"w");
	  //echo "͡G$fn1P$gbfn1<br>\n";
	  /****** ഫ *****/
	  $OUT1=str_replace("%oid%",$PARAW[0],$OUT1); //aid
	  $OUT1=str_replace("%title%",trim($PARAW[1]),$OUT1); //title
	  $OUT1=str_replace("%author%",trim($PARAW[2]),$OUT1); //author
	  $OUT1=str_replace("%pubtime%",$PARAW[3],$OUT1); //ptime
	  $OUT1=str_replace("%abst%",$PARAW[4],$OUT1); //abst
	  $OUT1=str_replace("%txt%",$PARAW[5],$OUT1); //txt
	  $OUT1=str_replace("%email%",trim($PARAW[6]),$OUT1); //email
	  $OUT1=str_replace("%username%",trim($PARAW[7]),$OUT1); //username
	  if ($tabmode)
	  {
		$BDMSG=str_replace("%title%",trim($PARAW[1]),$BDMSG);
		$BDMSG=str_replace("%author%",trim($PARAW[2]),$BDMSG);
		$BDMSG=str_replace("%pubtime%",trim($PARAW[3]),$BDMSG);
		$BDMSG=str_replace("%abst%",trim($PARAW[4]),$BDMSG);
		$BDMSG=str_replace("%txt%",trim($PARAW[5]),$BDMSG);
		$BDMSG=str_replace("%email%",trim($PARAW[6]),$BDMSG);
		$BDMSG=str_replace("%username%",trim($PARAW[7]),$BDMSG);
 	  }
	  if ($ALLYN)
	  {
		$k="{".trim($ARAW[0])."}T$j";
		$OUTMAIN=str_replace("%${k}title%",trim($PARAW[1]),$OUTMAIN);
	  	$OUTMAIN=str_replace("%${k}author%",trim($PARAW[2]),$OUTMAIN); 
	  	$OUTMAIN=str_replace("%${k}pubtime%",trim($PARAW[3]),$OUTMAIN);
	  	$OUTMAIN=str_replace("%${k}abst%",trim($PARAW[4]),$OUTMAIN);
	  	$OUTMAIN=str_replace("%${k}txt%",trim($PARAW[5]),$OUTMAIN);
	  	$OUTMAIN=str_replace("%${k}email%",trim($PARAW[6]),$OUTMAIN);
	  	$OUTMAIN=str_replace("%${k}username%",trim($PARAW[7]),$OUTMAIN);
	  }
	  if ($MAILYN)
	  {
		$k="{".trim($ARAW[0])."}T$j";
		$OUTMAIL=str_replace("%${k}title%",trim($PARAW[1]),$OUTMAIL);
	  	$OUTMAIL=str_replace("%${k}author%",trim($PARAW[2]),$OUTMAIL); 
	  	$OUTMAIL=str_replace("%${k}pubtime%",trim($PARAW[3]),$OUTMAIL);
	  	$OUTMAIL=str_replace("%${k}abst%",trim($PARAW[4]),$OUTMAIL);
	  	$OUTMAIL=str_replace("%${k}txt%",trim($PARAW[5]),$OUTMAIL);
	  	$OUTMAIL=str_replace("%${k}email%",trim($PARAW[6]),$OUTMAIL);
	  	$OUTMAIL=str_replace("%${k}username%",trim($PARAW[7]),$OUTMAIL);
	  }
	  $OUTIND=str_replace("%T${j}title%",trim($PARAW[1]),$OUTIND); 
	  $OUTIND=str_replace("%T${j}author%",trim($PARAW[2]),$OUTIND); 
	  $OUTIND=str_replace("%T${j}pubtime%",trim($PARAW[3]),$OUTIND);
	  $OUTIND=str_replace("%T${j}abst%",trim($PARAW[4]),$OUTIND);
	  $OUTIND=str_replace("%T${j}email%",trim($PARAW[6]),$OUTIND);
	  $OUTIND=str_replace("%T${j}username%",trim($PARAW[7]),$OUTIND);
	  $ofn1=trim($ARAW[0]).$PARAW[0].".html";
	  $OUTIND=str_replace("%T${j}url%",$ofn1,$OUTIND);
	  $OUT1=str_replace("%T${j}oid%",$PARAW[0],$OUT1); //aid
	  $OUT1=str_replace("%T${j}title%",trim($PARAW[1]),$OUT1); //title
	  $OUT1=str_replace("%T${j}author%",trim($PARAW[2]),$OUT1); //author
	  $OUT1=str_replace("%T${j}pubtime%",$PARAW[3],$OUT1); //ptime
	  $OUT1=str_replace("%T${j}abst%",$PARAW[4],$OUT1); //abst
	  $OUT1=str_replace("%T${j}txt%",$PARAW[5],$OUT1); //txt
	  $OUT1=str_replace("%T${j}email%",trim($PARAW[6]),$OUT1); //email
	  $OUT1=str_replace("%T${j}username%",trim($PARAW[7]),$OUT1); //username
	  if ($tabmode)
		$BDMSG=str_replace("%url%",$ofn1,$BDMSG);
	  if ($ALLYN)
	  {
	 	$mainofn1=trim($ARAW[0])."/".$ofn1;
	  	$OUTMAIN=str_replace("%${k}url%",$mainofn1,$OUTMAIN);
	  }
	  if ($MAILYN)
	  {
	 	$mailofn1=trim($ARAW[0])."/".$ofn1;
	  	$OUTMAIL=str_replace("%${k}url%",$mailofn1,$OUTMAIL);
	  }
	  $ofn1=trim($ARAW[0]).$PARAW1[0].".html";
	  $OUT1=str_replace("%next%",$ofn1,$OUT1); //next file
	  
	  $PARAW1=$PARAW;
	  if ($j<$numr)
   	  	$PARAW=db_fetch_row($res,$j); //Ū@M峹O
	  $fn1=$DESTDIR.trim($ARAW[0]).$PARAW[0].".html";
	  $gbfn1=$AUTOCONV." > ".$GBDESTDIR.trim($ARAW[0]).$PARAW[0].".html";
	  $ofn1=trim($ARAW[0]).$PARAW[0].".html";
	  $OUT1=str_replace("%prev%",$ofn1,$OUT1); //previous file
	  fputs($fp1,$OUT1);
	  $GBOUT1=str_replace("charset=big5","charset=gb2312",$OUT1);
	  fputs($gbfp1,$GBOUT1);
	  fclose($fp1);
	  pclose($gbfp1);
	  if ($j==1) //峹
	  {
	    $indfn=$DESTDIR.$NEWFILE;
	    $gbindfn=$AUTOCONV." > ".$GBDESTDIR.$NEWFILE;
	    //echo "big5=$indfn, $gbindfn<br>";
	    $fp1=fopen($indfn,"w");
	    $gbfp1=popen($gbindfn,"w");
	    fputs($fp1,$OUT1);
	    $GBOUT1=str_replace("charset=big5","charset=gb2312",$OUT1);
	    fputs($gbfp1,$GBOUT1);
	    fclose($fp1);
	    pclose($gbfp1);
	  }
	  if ($tabmode) $BDTXT=$BDTXT.$BDMSG;
	}
	db_freeresult($res);
	if ($tabmode)
		$OUTIND=str_replace("%body%",$BDTXT,$OUTIND);
        /**** 	X ******/
	$fnind=$DESTDIR.$INDFILE;
	$gbfnind=$AUTOCONV." > ".$GBDESTDIR.$INDFILE;
	$fpind=fopen($fnind,"w");
	$gbfpind=popen($gbfnind,"w");
	fputs($fpind,$OUTIND);
	$OUTIND=str_replace("charset=big5","charset=gb2312",$OUTIND);
	fputs($gbfpind,$OUTIND);
	fclose($fpind);
	pclose($gbfpind);
   }
 	db_freeresult($result);
	/***** X` ****/
	if ($ALLYN)
	{
		$fnind=$BASEDIR.$ALLIND;
		$gbfnind=$AUTOCONV." > ".$GBBASEDIR.$ALLIND;
		$fpind=fopen($fnind,"w");
		$gbfpind=popen($gbfnind,"w");
		fputs($fpind,$OUTMAIN);
		$OUTMAIN=str_replace("charset=big5","charset=gb2312",$OUTMAIN);
		fputs($gbfpind,$OUTMAIN);
		//echo "Bz $fnind, $gbfnind<br>\n";
		fclose($fpind);
		pclose($gbfpind);
	}
	/***** XqlAqlNBig5XYi ****/
	if ($MAILYN)
	{
		$fnind=$BASEDIR.$MAILIND;
		$fpind=fopen($fnind,"w");
		fputs($fpind,$OUTMAIL);
		fclose($fpind);
	}
?>
